@@ -10,5 +10,5 @@ research data, the plot is based on. Additionally, the script that created the
 plot will also be copied to the directory.
 """
 
-__version__ = '0.2.0'
-__author__ = 'Institut Fluidsystemtechnik within nfdi4ing at TU Darmstadt'
+__version__ = "0.2.2"
+__author__ = "Institut Fluidsystemtechnik within nfdi4ing at TU Darmstadt"
